@@ -38,7 +38,10 @@ export async function requestAPI<T>(
   }
 
   if (!response.ok) {
-    throw new ServerConnection.ResponseError(response, data.message);
+    throw new ServerConnection.ResponseError(
+      response,
+      data ? data.message : null
+    );
   }
 
   return data;
